#
# spec file for package termcap
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libcurses libcurses1
%define libtermcap libtermcap2

Name:           termcap
# bug437293
%ifarch ppc64
Obsoletes:      termcap-64bit
%endif
#
Version:        2.0.8
Release:        1049.5
Summary:        The Termcap Library
License:        LGPL-2.1-or-later
Group:          System/Libraries
Source:         termcap-2.0.8.tar.gz
Source1:        curses-bsd4.4.tar.gz
Source2:        baselibs.conf
Patch0:         termcap-2.0.8.dif
Patch1:         curses-bsd4.4-linux.patch
Patch2:         termcap-2.0.8-setuid.patch
Patch3:         termcap-2.0.8-fix-tc.patch

%description
The termcap and curses libraries.

%package -n %libcurses
Summary:        Library for old curses
Group:          System/Libraries
Version:        1.0.0
Provides:       termcap:%{_libdir}/libcurses.so.1.0.0
Obsoletes:      termcap <= 2.0.8

%description -n %libcurses
This library of old curses

%package -n %libtermcap
Summary:        Library for old termcap
Group:          System/Libraries
Version:        2.0.8
Provides:       termcap:%{_libdir}/libtermcap.so.2.0.8
Obsoletes:      termcap <= 2.0.8

%description -n %libtermcap
This library of old termcap

%package devel
Summary:        Development files for termcap
Group:          Development/Libraries/C and C++
Provides:       termcap:%{_includedir}/curses/curses.h
Requires:       %libcurses = 1.0.0
Requires:       %libtermcap = 2.0.8

%description devel
This package contains all necessary include files
and libraries needed to build termcap based applications.

%package devel-static
Summary:        Development files for termcap
Group:          Development/Libraries/C and C++
Provides:       termcap:%{_libdir}/termcap/libtermcap.a
Requires:       %{name}-devel

%description devel-static
This package contains all necessary include files
and libraries needed to build termcap based applications.

%prep
%setup -q -b 1
%patch -P 0 -p0
%patch -P 2 -p1 -b .setuid
%patch -P 3 -p1 -b .tc
cd ../curses-bsd4.4
%patch -P 1 -p0

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
mkdir termcap
ln -sf ../termcap.h termcap/
make -j1 lib=%{_lib} CC="%{__cc}"
cd ../curses-bsd4.4
make -j1 lib=%{_lib} CC="%{__cc}"

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}
make install prefix=%{buildroot}%{_prefix} lib=%{_lib}
cd ../curses-bsd4.4
make install prefix=%{buildroot}%{_prefix} lib=%{_lib}
find %{buildroot} \( -name '*.h' -o -name '*.a' \) -exec chmod 644 '{}' \+

%post -n %libcurses -p /sbin/ldconfig
%postun -n %libcurses -p /sbin/ldconfig

%post -n %libtermcap -p /sbin/ldconfig
%postun -n %libtermcap -p /sbin/ldconfig

%files -n %libcurses
%{_libdir}/libcurses.so.1
%{_libdir}/libcurses.so.1.0.0

%files -n %libtermcap
%{_libdir}/libtermcap.so.2
%{_libdir}/libtermcap.so.2.0.8

%files devel
%dir %{_includedir}/curses
%dir %{_includedir}/termcap
%dir %{_libdir}/curses
%dir %{_libdir}/termcap
%{_includedir}/curses/curses.h
%{_includedir}/termcap/termcap.h
%{_libdir}/curses/libcurses.so
%{_libdir}/termcap/libtermcap.so

%files devel-static
%{_libdir}/curses/libcurses.a
%{_libdir}/termcap/libtermcap.a

%changelog
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Oct 20 2023 Dr. Werner Fink <werner@suse.de>
- Create a devel-static sub packages for static libs as well
* Thu Oct 12 2023 Dr. Werner Fink <werner@suse.de>
- Rework package to make it build again
* Thu Oct 12 2023 Dr. Werner Fink <werner@suse.de>
- New RPM API change ... now no %%patch anymore only %%patch0
* Sat Nov 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Convert changes file to proper UTF-8 format: new
  version of RPM are getting strict in interpreting files.
* Fri Aug  2 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Thu Oct  4 2018 schwab@suse.de
- curses-bsd4.4-linux.patch: remove use of internal macro name
- Don't unpack Source0 twice
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Tue Feb 15 2011 coolo@novell.com
- disable parallel build, it can break
* Tue Nov 16 2010 meissner@suse.de
- use ln -sf instead of ln -s if we ever enter make install
  twice (fix for a ppc time issue).
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Mon Oct 26 2009 meissner@suse.de
- fixed implicit setfsuid and setfsgid, check their return values.
- fixed implicit abort()
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 21 2005 werner@suse.de
- Remove one of two __END_DECLS (bug #140467)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Jul 28 2003 werner@suse.de
- Increase possible size of termcap entry
- Fix tc entry resolver
- Add fsuid/fsgid wrapper for suid programs
* Thu Feb 14 2002 werner@suse.de
- Move the string lib to %%_lib which depends on architecture
* Fri Oct 13 2000 werner@suse.de
- use old BSD curses for compiling libcurses
* Fri Oct  6 2000 kukuk@suse.de
- change group tag
* Sun Oct  1 2000 kukuk@suse.de
- Fix for glibc 2.2
* Sun Nov 28 1999 kukuk@suse.de
- Include binary only libcurses only on Intel
- Don't build ignored info pages, remove tetex dependency
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 18 1999 kukuk@suse.de
- Check for possible buffer overflow
* Wed Jul 28 1999 schwab@suse.de
- Correctly handle \072 and \\
* Fri Oct 17 1997 ro@suse.de
- curses 1.0.0 binary used
  ready for autobuild
  Tue Sep  3 12:07:47 MET DST 1996
  libcurses added.
  die libbcurses.so.1.0.0 bzw. libcurses.a sind aber aus der November und mit
  gcc 2.6.4 übersetzt (original Slackware).  Was fehlt, sind die Sourcen,
  die Patrick Volkerding verwendete ... die sind auf unserem Mirror nicht
  zu finden ... nur eine wesentlich ältere Version.
